@@ -4,11 +4,12 @@ from sense_push.common import *
 
 class SensePushConsumer(object):
 
-    def __init__(self, handler, table=None, retry_times=0):
+    def __init__(self, handler, table=None, retry_times=0, check_log_receive=None):
         super(SensePushConsumer, self).__init__()
         self.table = table
         self.handler = handler
         self.retry_times = retry_times
+        self.check_log_receive = check_log_receive
 
     @sd.try_catch_exception
     def consume_queue(self, label=None, config_info=None, queue=None):
@@ -24,7 +25,8 @@ class SensePushConsumer(object):
         table = message2.get('table')
         if self.table and self.table != table:
             return
-        sd.log_info("start _handle_message0 {0}".format(message))
+        if not self.check_log_receive or self.check_log_receive(table):
+            sd.log_info("start _handle_message0 {0}".format(message))
         action = message2.get('action')
         database = message2.get('db')
         data = message2.get('data')
@@ -38,7 +40,7 @@ class SensePushConsumer(object):
         elif action == PUSH_ACTION_DELETE:
             self.delete(database=database, table=table, data=data)
         else:
-            sd.log_warn("invalid message {}".format(message))
+            self.handle_custom(database=database, table=table, data=data, action=action)
 
     def insert(self, database, table, data):
         self.handler.insert(database, table, data)
@@ -48,3 +50,6 @@ class SensePushConsumer(object):
 
     def delete(self, database, table, data):
         self.handler.delete(database, table, data)
+
+    def handle_custom(self, database, table, data, action):
+        self.handler.handle_custom(database, table, data, action)
