@@ -5,6 +5,7 @@ import pymysql
 from sense_push.core.data import PushDataHandler
 import datetime
 
+
 class SensePushManager(object):
 
     def __init__(self, queue_label=None, db_label=None, queue_configs=None, db_config=None, database=None, queue=None):
@@ -40,7 +41,7 @@ class SensePushManager(object):
             config[key] = sd.config(label, key, '')
         return config
 
-    def push_table_all_data(self, table, build_sql=None, limit=0):
+    def push_table_all_data(self, table, build_sql=None, limit=0, primary_key=None):
         offset = 0
         queue_configs = self.queue_configs
         db_config = self.db_config
@@ -55,6 +56,8 @@ class SensePushManager(object):
                     if type(value) == datetime.datetime:
                         item[key] = str(value)
                 handler.insert_data(item)
+                if primary_key:
+                    sd.log_info("insert_data for {}".format(item.get(primary_key)))
             if len(items) < limit or limit <= 0:
                 break
             offset += limit
